It-twettiq ta’ valutazzjoni tar-riskji bl-OiRA | OiRA

Temi

# It-twettiq ta’ valutazzjoni tar-riskji bl-OiRA

## Il-bidu ta’ sessjoni ġdida

Sabiex tibda valutazzjoni tar-riskji ġdida, ikklikkja l-link “Ibda sessjoni ġdida”.

## Il-ftuħ ta’ valutazzjoni tar-riskji

Ladarba tkun bdejt valutazzjoni tar-riskji, tista’ tirkupraha fi kwalunkwe ħin permezz tad-daxxbord taħt l-intestatura “Il-valutazzjonijiet tar-riskji tiegħi”. Minn hawn tista’ wkoll tibda valutazzjoni tar-riskji ġdida.

Id-daxxbord.

## In-navigazzjoni ta’ valutazzjoni tar-riskji

Kull valutazzjoni tar-riskji tiggwidak permezz ta’ diversi stadji. Dawn jidhru fil-menu prinċipali fuq in-naħa tax-xellug tal-iskrin:

- Preparazzjoni
- Involviment
- Identifikazzjoni + Evalwazzjoni
- Pjan ta’ azzjoni
- Rapport
- Status

Skont id-deċiżjonijiet meħuda mis-sħab/mill-iżviluppaturi tal-għodda tal-OiRA, l-istruttura ta’ kull għodda tista’ tvarja. F’xi għodod, l-istadju tal-identifikazzjoni u l-evalwazzjoni tar-riskji jinkludi l-pjan ta’ azzjoni. F’dan il-każ, il-menu fuq ix-xellug jidher kif ġej:

- Preparazzjoni
- Involviment
- Valutazzjoni
- Rapport
- Status

## Preparazzjoni

“Preparazzjoni” hija fejn tibda kull sessjoni/għodda. Dan l-istadju huwa fejn tagħti isem lill-valutazzjoni tar-riskji li aktar tard jgħinek tiddistingwi bejn diversi valutazzjonijiet tar-riskji differenti li tkun wettaqt bl-għodda.

Il-link “Tgħallem aktar dwar din l-għodda…” tipprovdi aktar informazzjoni dwar l-għodda magħżula u l-partijiet involuti fl-iżvilupp tagħha.

Wara li tikklikkja “Ibda”, jistgħu jsiru xi mistoqsijiet addizzjonali, skont l-għodda li tkun qed tuża. Dan l-iskrin ta’ preparazzjoni b’“mistoqsijiet dwar il-profil” jidher biss b’għodod li joffru din l-għażla.

Hawnhekk, inti tista’:

- Tagħżel jew taqbeż is-sitwazzjoni(jiet) skont jekk japplikawx għall-attività kummerċjali tiegħek. Agħżel “iva” fejn xieraq.
- Telenka diversi unitajiet tan-negozju, fergħat jew ħwienet, eċċ. Ir-riskji relatati se jiġu ripetuti għal kull entrata.

L-iskrin “Profil” fl-istadju ta’ Preparazzjoni

L-istadju tal-preparazzjoni huwa importanti ħafna, minħabba li jiddefinixxi b’mod preċiż it-tip ta’ negozju u r-riskji relatati li tiffaċċja l-kumpanija tiegħek. Wara li tikklikkja “Issejvja u kompli” se titmexxa għat-taqsima li jmiss, “Involviment”.

Nota: Ħafna għodod ma għandhomx mistoqsijiet dwar il-profil, minħabba li ma jużawx dan l-element għall-immirar tal-għodda. F’dan il-każ, dan l-iskrin jinqabeż awtomatikament.

## Involviment

Dan l-istadju huwa tfakkira tal-importanza tal-involviment tal-ħaddiema u jippreżenta modi differenti biex jiġi żgurat l-involviment tajjeb tal-ħaddiema. Hawnhekk tista’ tniżżel jew tistampa l-kontenut tal-valutazzjoni tar-riskji biex tikkondividih mal-ħaddiema/impjegati tiegħek. Dan jiżgura li l-ħaddiema jkunu jistgħu jikkontribwixxu għall-kompitu li jivvalutaw is-sitwazzjoni fuq il-post tax-xogħol tagħhom.

## Valutazzjoni

F’dan l-istadju se tidentifika l-perikli u l-problemi rilevanti għall-kumpanija tiegħek.

Nota: Skont kif l-għodda ġiet ikkonfigurata mis-sieħeb tal-OiRA, l-istadju tal-“Pjan ta’ azzjoni” (ara hawn taħt) jista’ jiġi integrat f’dan l-iskrin. F’dan il-każ, l-istadju kollu jissejjaħ “Valutazzjoni”, u l-elementi deskritti taħt “Pjan ta’ azzjoni” se jidhru taħt l-identifikazzjoni u l-evalwazzjoni ta’ kull riskju.

Identifikazzjoni u Evalwazzjoni.

Fuq ix-xellug tal-iskrin, taħt “Identifikazzjoni + Evalwazzjoni”/“Valutazzjoni”, tista’ tara kull wieħed mis-suġġetti/mill-moduli inklużi fl-għodda. Is-suġġett li qed tara bħalissa huwa enfasizzat.

### Identifikazzjoni

Għal kull riskju, inti għandek tiddeċiedi jekk id-dikjarazzjoni li tiddeskrivi stat mixtieq tapplikax għall-kumpanija tiegħek. Tista’ twieġeb kif ġej:

- Iva: jekk twieġeb għad-dikjarazzjoni b’“iva”, ma hija meħtieġa l-ebda azzjoni ulterjuri, billi tkun ivvalutajt ir-riskju bħala mhux preżenti.
- Le: jekk twieġeb għad-dikjarazzjoni b’“le”, għandha tittieħed azzjoni ulterjuri. Inti se tintalab tiddeċiedi dwar miżuri speċifiċi.
- Mhux applikabbli: xi dikjarazzjonijiet tar-riskji jagħtuk l-għażla li tagħżel “mhux applikabbli” jekk ir-riskju ma jkunx rilevanti għall-kumpanija/istabbiliment tiegħek.

Taħt kull dikjarazzjoni ġeneralment ikun hemm aktar informazzjoni dwar ir-riskju speċifiku:

- Informazzjoni: deskrizzjoni qasira, xi drabi bi stampi li jakkumpanjawha, li tipprovdi aktar dettalji dwar ir-riskju.
- Riżorsi: informazzjoni addizzjonali dwar ir-riskju, bħal referenzi legali u ta’ politika. Xi drabi tista’ ssib ukoll dokumenti mehmuża hawnhekk għal aktar qari.
- Kummenti: tista’ ddaħħal il-kummenti tiegħek hawnhekk, li se jiġu jidhru fir-rapport tiegħek fi tmiem il-valutazzjoni.

Wara li twieġeb għal dikjarazzjoni tar-riskji u tipproċedi, il-menu fuq ix-xellug jiġi aġġornat b’simbolu kkulurit biex jindika jekk inti:

- weġibtx b’mod pożittiv (marka ħadra)
- weġibtx b’mod negattiv (salib aħmar)
- ipposponejtx (simbolu ta’ mistoqsija oranġjo)

Għal mistoqsijiet mhux imwieġba, jibqa’ s-simbolu griż.

### Evalwazzjoni

F’dan l-istadju tevalwa l-prijorità ta’ riskju li tkun identifikajt.

L-evalwazzjoni ta’ riskju.

Nota: F’xi għodod tal-OiRA, l-evalwazzjoni ma tintweriex. Dan jiddependi minn kif is-sieħeb nazzjonali/l-iżviluppatur tal-għodda tal-OiRA stabbilixxa l-għodda tal-OiRA partikolari tiegħu.

Jekk tkun identifikajt riskju bħala preżenti (muri permezz ta’ salib aħmar), tiġi tidher it-taqsima għall-evalwazzjoni. Skont il-metodu ta’ evalwazzjoni stabbilit għal kull riskju, inti se tintalab:

- tistma l-prijorità: għolja, medja jew baxxa

L-istabbiliment tal-prijorità ta’ riskju.

JEW

- wieġeb ftit mistoqsijiet dwar il-frekwenza, is-severità u l-probabbiltà tar-riskju, sabiex il-prijorità tkun tista’ tiġi kkalkolata abbażi tat-tweġibiet tiegħek.

L-istabbiliment ta’ varjabbli għal riskju.

### Riskji ta’ prijorità stabbiliti mis-settur:

Xi riskji huma meqjusa bħala importanti ħafna mis-sieħeb nazzjonali jew mill-iżviluppatur tal-għodda li ħoloq l-għodda tal-OiRA speċifika. Inti mintix meħtieġ li tistma dawn ir-“riskji ta’ prijorità”, billi l-prijorità tagħhom se tiġi stabbilita awtomatikament għal “għolja”.

Riskji ta’ prijorità.

### Riskji personalizzati

Wara li tkun lestejt twieġeb is-suġġetti kollha tar-riskju taħt “Identifikazzjoni + Evalwazzjoni”/“Valutazzjoni”, se tasal għas-suġġett fakultattiv “Riskji oħrajn”. Hawnhekk, il-buttuna “Żid riskju personalizzat” tħallik toħloq l-entrati tiegħek stess.

Jekk hemm riskji neqsin fl-għodda li huma preżenti fuq il-post tax-xogħol tiegħek/fil-kumpanija tiegħek, inti trid iżżidhom hawnhekk. Dawn ir-riskji jistgħu jiġu definiti kompletament/ifformulati minnek.

Riskji personalizzati.

“Riskju personalizzat” jaħdem b’mod simili ħafna għar-riskji pprovduti mill-għodda tal-OiRA, iżda ovvjament inti trid tikteb it-test tiegħek stess. Dan it-test għandu mill-inqas ikun dikjarazzjoni qasira li tiddeskrivi sitwazzjoni problematika, bl-għażla ta’ deskrizzjoni itwal. Tista’ wkoll ittella’ stampa biex turi sitwazzjoni partikolari.

Bħal fil-każ tar-riskji regolari, inti trid tiddikjara jekk ir-riskju huwiex preżenti jew le. Dan jippermettilek timmarka r-riskji personalizzati ladarba tkun indirizzajthom b’suċċess, iżda għandek iżżommhom fil-valutazzjoni tar-riskji tiegħek għal finijiet ta’ dokumentazzjoni.

Tista’ żżid riskji personalizzati kemm għandek bżonn.

Żid riskju personalizzat.

## Pjan ta’ azzjoni

F’dan l-istadju, inti tiddeċiedi dwar il-miżuri li trid timplimenta biex telimina jew ittaffi r-riskji li tkun identifikajt qabel.

Nota: Kif imsemmi hawn fuq, il-pjan ta’ azzjoni jiġi ppreżentat bħala stadju separat fil-menu fuq ix-xellug jew jiġi jidher taħt kull riskju identifikat. Fil-każ tal-aħħar, l-istadju fil-menu jissejjaħ “Valutazzjoni” u jinkludi kemm id-dikjarazzjonijiet tar-riskji kif ukoll għażla ta’ tweġibiet.

L-għażla tal-verżjoni li tiġi pprovdut biha tiddependi mid-deċiżjonijiet meħuda mis-sieħeb nazzjonali/mill-iżviluppatur tal-għodda tal-OiRA.

### Pjan ta’ azzjoni integrat

Pjan ta’ azzjoni integrat.

Jekk twieġeb mistoqsija b’“le”, mela l-modulu tal-pjan ta’ azzjoni jinfetaħ fuq il-paġna, taħt l-intestatura “Miżuri”.

Tista’ kemm tagħżel minn lista ta’ miżuri proposti mis-sistema, kif ukoll tiddefinixxi l-miżuri tiegħek stess.

### Pjan ta’ azzjoni separat

Meta l-pjan ta’ azzjoni jkun stadju separat, dan ikun aċċessibbli permezz tan-navigazzjoni fuq in-naħa tax-xellug.

Ikklikkja l-buttuna “Oħloq pjan ta’ azzjoni” biex tibda l-pjan tiegħek.

Fl-istadju tal-pjan ta’ azzjoni, il-menu fuq ix-xellug issa juri biss ir-riskji mmarkati għal azzjoni ulterjuri, billi r-riskji l-oħrajn ġew immarkati bħala mhux preżenti.

Għal kull riskju mwieġeb “le” matul il-proċess ta’ evalwazzjoni u għal riskji ta’ prijorità (irrispettivament minn jekk ġewx imwieġba b’mod pożittiv jew negattiv), inti se tintalab tiddefinixxi l-miżuri.

Riskju fil-pjan ta’ azzjoni.

Tista’ jew tagħżel minn lista ta’ miżuri ssuġġeriti mis-sistema jew inkella tiddefinixxi l-miżuri tiegħek stess.

#### Żid il-miżura tiegħek stess

Iż-żieda ta’ miżura addizzjonali.

Uża l-buttuna “Żid miżura” biex tibda tiddefinixxi miżura preventiva. Inti għandek:

- Tiddeskrivi l-approċċ ġenerali li se jittieħed biex jiġi eliminat jew jitnaqqas ir-riskju.
- B’mod fakultattiv tiddikjara l-livell ta’ għarfien espert u/jew ir-rekwiżiti meħtieġa (eż. hawnhekk tista’ żżid jekk huwiex meħtieġ taħriġ speċifiku jew għarfien espert estern biex jiġi indirizzat dan ir-riskju)
- Iddaħħal informazzjoni dwar min huwa responsabbli mill-implimentazzjoni.
- Tiddefinixxi baġit, jekk applikabbli.
- B’mod fakultattiv tistabbilixxi d-dati ta’ meta għandek tibda timplimenta l-miżura u meta tippjana li tlestiha.

Tista’ żżid miżuri kemm hemm bżonn.

#### Żid miżuri standard

Skont kif is-sieħeb/l-iżviluppatur tal-għodda tal-OiRA jkun stabbilixxa l-għodda, huma disponibbli miżuri predefiniti għal riskji individwali. Sabiex tagħżel miżura predefinita waħda jew aktar, ikklikkja l-buttuna “Agħżel miżuri standard”.

Jinfetaħ menu pop-up li juri l-miżuri kollha ssuġġeriti. Ikklikkja l-buttuna “Żid” għal dawk li tixtieq tuża.

Il-miżuri predefiniti mbagħad jiġu elenkati fil-pjan ta’ azzjoni tiegħek. Id-deskrizzjoni ta’ x’għandek tagħmel hija fissa, iżda l-oqsma l-oħrajn (ir-responsabbiltà, il-baġit, id-dati) jistgħu u għandhom jimtlew minnek.

Iż-żieda ta’ miżuri standard.

Kemm il-miżuri standard kif ukoll il-miżuri definiti minnek jistgħu jerġgħu jitħassru fi kwalunkwe punt.

## Rapport

Wara li tiffinalizza l-pjan ta’ azzjoni, tista’ tipproduċi rapport.

Jekk tixtieq tħalli kumment biex jiġi inkluż fir-rapport, ittajpja t-test tiegħek hawnhekk u ssejvjah.

Kif tħalli kumment fir-rapport.

Ara hawnhekk biex taqra aktar dwar ir-rapporti differenti u kif tużahom.

## Status

Il-pie chart żgħira fil-menu fuq ix-xellug turik il-progress li għamilt bl-għodda.

It-taqsima dwar l-istatus tipprovdi ħarsa ġenerali dwar kemm-il riskju identifikajt, kemm minnhom indirizzajt billi ddeċidejt dwar miżuri u kemm hemm riskji/dikjarazzjonijiet li għadek ma weġibtx għalihom.

Il-paġna tal-istatus.

Meta tidħol fl-iskrin tal-istatus, tista’ tara kemm għamilt progress f’kull modulu. Dan jista’ jgħinek tinnota fejn għad trid tivvaluta r-riskji jew tipprovdi miżuri għal dawk ir-riskji li identifikajt.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More